@@ -160,6 +160,11 @@ grl_apple_trailers_source_new (gboolean high_definition,
   GrlAppleTrailersSource *source;
   GIcon *icon;
   GFile *file;
+  const char *tags[] = {
+    "country:us",
+    "cinema",
+    NULL
+  };
 
   GRL_DEBUG ("grl_apple_trailers_source_new%s%s",
              high_definition ? " (HD)" : "",
@@ -175,7 +180,9 @@ grl_apple_trailers_source_new (gboolean high_definition,
                          "high-definition", high_definition,
 			 "large-poster", xlarge,
                          "source-icon", icon,
+                         "source-tags", tags,
                          NULL);
+  g_object_unref (icon);
 
   return source;
 }
@@ -189,8 +196,7 @@ grl_apple_trailers_source_finalize (GObject *object)
 
   self = GRL_APPLE_TRAILERS_SOURCE (object);
 
-  if (self->priv->wc)
-    g_object_unref (self->priv->wc);
+  g_clear_object (&self->priv->wc);
 
   G_OBJECT_CLASS (grl_apple_trailers_source_parent_class)->finalize (object);
 }
@@ -483,8 +489,10 @@ xml_parse_result (const gchar *str, OperationData *op_data)
   if (!node) {
     goto finalize;
   } else {
+    guint id;
     op_data->xml_entries = node;
-    g_idle_add ((GSourceFunc) send_movie_info, op_data);
+    id = g_idle_add ((GSourceFunc) send_movie_info, op_data);
+    g_source_set_name_by_id (id, "[apple-trailers] send_movie_info");
   }
 
   return;
@@ -497,14 +505,8 @@ xml_parse_result (const gchar *str, OperationData *op_data)
                          op_data->bs->user_data,
                          error);
 
-  if (op_data->xml_doc) {
-    xmlFreeDoc (op_data->xml_doc);
-  }
-
-  if (error) {
-    g_error_free (error);
-  }
-
+  g_clear_pointer (&op_data->xml_doc, (GDestroyNotify) xmlFreeDoc);
+  g_clear_error (&error);
   g_object_unref (op_data->cancellable);
   g_slice_free (OperationData, op_data);
 }
