@@ -151,17 +151,21 @@ grl_bliptv_source_new (void)
 {
   GIcon *icon;
   GFile *file;
+  GrlBliptvSource *source;
 
   file = g_file_new_for_uri ("resource:///org/gnome/grilo/plugins/bliptv/channel-bliptv.svg");
   icon = g_file_icon_new (file);
   g_object_unref (file);
-  return g_object_new (GRL_TYPE_BLIPTV_SOURCE,
-                       "source-id", SOURCE_ID,
-                       "source-name", SOURCE_NAME,
-                       "source-desc", SOURCE_DESC,
-                       "supported-media", GRL_MEDIA_TYPE_VIDEO,
-                       "source-icon", icon,
-                       NULL);
+  source = g_object_new (GRL_TYPE_BLIPTV_SOURCE,
+                         "source-id", SOURCE_ID,
+                         "source-name", SOURCE_NAME,
+                         "source-desc", SOURCE_DESC,
+                         "supported-media", GRL_MEDIA_TYPE_VIDEO,
+                         "source-icon", icon,
+                         NULL);
+  g_object_unref (icon);
+
+  return source;
 }
 
 static void
@@ -170,10 +174,8 @@ grl_bliptv_source_dispose (GObject *object)
   GrlBliptvSource *self;
 
   self= GRL_BLIPTV_SOURCE (object);
-  if (self->priv->wc) {
-    g_object_unref (self->priv->wc);
-    self->priv->wc = NULL;
-  }
+
+  g_clear_object (&self->priv->wc);
 
   G_OBJECT_CLASS (grl_bliptv_source_parent_class)->dispose (object);
 }
@@ -249,12 +251,10 @@ bliptv_setup_mapping (void)
 static void
 bliptv_operation_free (BliptvOperation *op)
 {
-  if (op->cancellable)
-    g_object_unref (op->cancellable);
-  if (op->source)
-    g_object_unref (op->source);
-  if (op->url)
-    g_free (op->url);
+  g_clear_object (&op->cancellable);
+  g_clear_object (&op->source);
+  g_clear_pointer (&op->url, (GDestroyNotify) g_free);
+
   g_slice_free (BliptvOperation, op);
 }
 
@@ -319,9 +319,7 @@ call_raw_async_cb (GObject *     source_object,
   if (nb_items == 1) {
     obj = xmlXPathEvalExpression ((xmlChar *) "string(/rss/channel/item[0]/blip:item_id)", xpath);
     if (!obj || !obj->stringval || obj->stringval[0] == '\0') {
-      if (obj) {
-        xmlXPathFreeObject (obj);
-      }
+      g_clear_pointer (&obj, (GDestroyNotify) xmlXPathFreeObject);
       nb_items = 0;
       goto finalize_send_last;
     } else {
@@ -439,10 +437,8 @@ call_raw_async_cb (GObject *     source_object,
   }
 
  finalize_free:
-  if (xpath)
-    xmlXPathFreeContext (xpath);
-  if (doc)
-    xmlFreeDoc (doc);
+  g_clear_pointer (&xpath, (GDestroyNotify) xmlXPathFreeContext);
+  g_clear_pointer (&doc, (GDestroyNotify) xmlFreeDoc);
 }
 
 /* ================== API Implementation ================ */
