@@ -392,12 +392,10 @@ file_is_valid_content (GFileInfo *info, gboolean fast, GrlOperationOptions *opti
   }
 
  end:
-  if (file_date)
-    g_date_time_unref (file_date);
-  if (min_date)
-    g_date_time_unref (min_date);
-  if (max_date)
-    g_date_time_unref (max_date);
+  g_clear_pointer (&file_date, g_date_time_unref);
+  g_clear_pointer (&min_date, g_date_time_unref);
+  g_clear_pointer (&max_date, g_date_time_unref);
+
   return is_media;
 }
 
@@ -534,6 +532,8 @@ produce_from_uri (GrlSourceBrowseSpec *bs, const gchar *uri, GrlOperationOptions
 
   /* Emit results */
   if (entries) {
+    guint id;
+
     /* Use the idle loop to avoid blocking for too long */
     BrowseIdleData *idle_data = g_slice_new (BrowseIdleData);
     gint global_count = grl_operation_options_get_count (bs->options);
@@ -548,7 +548,8 @@ produce_from_uri (GrlSourceBrowseSpec *bs, const gchar *uri, GrlOperationOptions
                          GUINT_TO_POINTER (bs->operation_id),
                          idle_data->cancellable);
 
-    g_idle_add (browse_emit_idle, idle_data);
+    id = g_idle_add (browse_emit_idle, idle_data);
+    g_source_set_name_by_id (id, "[filesystem] browse_emit_idle");
   } else {
     /* No results */
     bs->callback (bs->source,
@@ -700,6 +701,10 @@ recursive_operation_got_entry (GFile *directory, GAsyncResult *res, RecursiveOpe
 
   enumerator = g_file_enumerate_children_finish (directory, res, &error);
   if (error) {
+    if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
+      g_error_free (error);
+      return;
+    }
     GRL_WARNING ("Got error: %s", error->message);
     g_error_free (error);
     /* we couldn't get the children of this directory, but we probably have
@@ -909,11 +914,7 @@ notify_parent_change (GrlSource *source, GFile *child, GrlSourceChangeType chang
   media = grl_pls_file_to_media (NULL, parent ? parent : child, NULL, fs_source->priv->handle_pls, options);
   grl_source_notify_change (source, media, change, FALSE);
   g_object_unref (media);
-
-  if (parent) {
-    g_object_unref (parent);
-  }
-
+  g_clear_object (&parent);
   g_object_unref (options);
 }
 
