@@ -30,6 +30,7 @@
 #include <grilo.h>
 #include <gio/gio.h>
 #include <glib/gi18n-lib.h>
+#include <libmediaart/mediaart.h>
 
 #include "grl-local-metadata.h"
 
@@ -435,9 +436,7 @@ got_file_info (GFile *file,
   /* Free stored operation data */
   cancellable = grl_operation_get_data (rs->operation_id);
 
-  if (cancellable) {
-    g_object_unref (cancellable);
-  }
+  g_clear_object (&cancellable);
 
   info = g_file_query_info_finish (file, result, &error);
   if (error)
@@ -487,8 +486,7 @@ error:
     }
 
 exit:
-  if (info)
-    g_object_unref (info);
+    g_clear_object (&info);
 }
 
 static void
@@ -604,198 +602,25 @@ resolve_image (GrlSource *source,
   return TRUE;
 }
 
-/* Taken from: http://live.gnome.org/MediaArtStorageSpec/SampleStripCodeInC */
-static gboolean
-strip_find_next_block (const gchar    *original,
-                       const gunichar  open_char,
-                       const gunichar  close_char,
-                       gint           *open_pos,
-                       gint           *close_pos)
-{
-  const gchar *p1, *p2;
-
-  if (open_pos)
-    *open_pos = -1;
-
-  if (close_pos)
-    *close_pos = -1;
-
-  p1 = g_utf8_strchr (original, -1, open_char);
-  if (p1) {
-    if (open_pos)
-      *open_pos = p1 - original;
-
-    p2 = g_utf8_strchr (g_utf8_next_char (p1), -1, close_char);
-    if (p2) {
-      if (close_pos)
-        *close_pos = p2 - original;
-
-      return TRUE;
-    }
-  }
-
-  return FALSE;
-}
-
-
-/* Taken from: http://live.gnome.org/MediaArtStorageSpec/SampleStripCodeInC
- * strips out invalid characters in a album name or artist name before md5sum
- * to get the unique identifier to find the album art.
- */
-static gchar *
-albumart_strip_invalid_entities (const gchar *original)
-{
-  GString         *str_no_blocks;
-  gchar          **strv;
-  gchar           *str, *res;
-  gboolean         blocks_done = FALSE;
-  const gchar     *p;
-  const gchar     *invalid_chars = "()[]<>{}_!@#$^&*+=|\\/\"'?~";
-  const gchar     *invalid_chars_delimiter = "*";
-  const gchar     *convert_chars = "\t";
-  const gchar     *convert_chars_delimiter = " ";
-  const gunichar   blocks[5][2] = {
-      { '(', ')' },
-      { '{', '}' },
-      { '[', ']' },
-      { '<', '>' },
-      {  0,   0  }
-  };
-
-  str_no_blocks = g_string_new ("");
-
-  p = original;
-
-  while (!blocks_done) {
-    gint pos1, pos2, i;
-
-    pos1 = -1;
-    pos2 = -1;
-
-    for (i = 0; blocks[i][0] != 0; i++) {
-      gint start, end;
-
-      /* Go through blocks, find the earliest block we can */
-      if (strip_find_next_block (p, blocks[i][0], blocks[i][1], &start,
-                                 &end)) {
-        if (pos1 == -1 || start < pos1) {
-          pos1 = start;
-          pos2 = end;
-        }
-      }
-    }
-
-    /* If either are -1 we didn't find any */
-    if (pos1 == -1) {
-      /* This means no blocks were found */
-      g_string_append (str_no_blocks, p);
-      blocks_done = TRUE;
-    } else {
-      /* Append the test BEFORE the block */
-      if (pos1 > 0)
-        g_string_append_len (str_no_blocks, p, pos1);
-
-      p = g_utf8_next_char (p + pos2);
-
-      /* Do same again for position AFTER block */
-      if (*p == '\0')
-        blocks_done = TRUE;
-    }
-  }
-
-  str = g_string_free (str_no_blocks, FALSE);
-
-  /* Now strip invalid chars */
-  g_strdelimit (str, invalid_chars, *invalid_chars_delimiter);
-  strv = g_strsplit (str, invalid_chars_delimiter, -1);
-  g_free (str);
-  str = g_strjoinv (NULL, strv);
-  g_strfreev (strv);
-
-  /* Now convert chars */
-  g_strdelimit (str, convert_chars, *convert_chars_delimiter);
-  strv = g_strsplit (str, convert_chars_delimiter, -1);
-  g_free (str);
-  str = g_strjoinv (convert_chars_delimiter, strv);
-  g_strfreev (strv);
-
-  /* Now remove double spaces */
-  strv = g_strsplit (str, "  ", -1);
-  g_free (str);
-  str = g_strjoinv (" ", strv);
-  g_strfreev (strv);
-
-  /* Now strip leading/trailing white space */
-  g_strstrip (str);
-
-  res = g_utf8_strdown (str, -1);
-  g_free (str);
-
-  str = g_utf8_normalize (res, -1, G_NORMALIZE_NFKD);
-  g_free (res);
-
-  return str;
-}
-
 static gboolean
 resolve_album_art (GrlSource *source,
                    GrlSourceResolveSpec *rs,
                    resolution_flags_t flags)
 {
-  const gchar *artist_value, *album_value;
-  gchar *artist, *album, *artist_tmp, *album_tmp,
-        *artist_md5, *album_md5, *file_path;
+  const gchar *artist, *album;
+  char *thumbnail_uri;
 
-  GRegex *regex;
+  artist = grl_media_audio_get_artist (GRL_MEDIA_AUDIO (rs->media));
+  album = grl_media_audio_get_album (GRL_MEDIA_AUDIO (rs->media));
 
-  artist_value = grl_media_audio_get_artist (GRL_MEDIA_AUDIO (rs->media));
-  album_value = grl_media_audio_get_album (GRL_MEDIA_AUDIO (rs->media));
-
-  if (!artist_value || !album_value)
+  if (!artist || !album)
     return TRUE;
 
-  /* regex to find if we need to strip invalid chars
-   * ()[]<>{}_!@#$^&*+=|\\/\"'?~" and 2 or more spaces
-   */
+  media_art_get_path (artist, album, "album", NULL, NULL, &thumbnail_uri);
 
-  regex =
-    g_regex_new ("([\\(\\)\\[\\]\\<\\>\\{\\}_!@#$\\^&\\*"
-                 "\\+=\\|\\\\/\\\"\\'\?~]|\\s{2,})",
-                 0, 0, NULL);
-
-  if ((g_regex_match (regex, artist_value, 0, NULL))) {
-    artist = albumart_strip_invalid_entities (artist_value);
-  } else {
-    artist_tmp = g_utf8_strdown (artist_value, -1);
-    artist = g_utf8_normalize (artist_tmp, -1, G_NORMALIZE_NFKD);
-    g_free (artist_tmp);
-  }
-
-  if (g_regex_match (regex, album_value, 0, NULL)) {
-    album = albumart_strip_invalid_entities (album_value);
-  } else {
-    album_tmp = g_utf8_strdown (album_value, -1);
-    album = g_utf8_normalize (album_tmp, -1, G_NORMALIZE_NFKD);
-    g_free (album_tmp);
-  }
-
-  g_regex_unref (regex);
-
-  artist_md5 = g_compute_checksum_for_string (G_CHECKSUM_MD5, artist, -1);
-  album_md5 = g_compute_checksum_for_string (G_CHECKSUM_MD5, album, -1);
-
-  file_path = g_strdup_printf ("%s/media-art/album-%s-%s.jpeg",
-                               g_get_user_cache_dir (),
-                               artist_md5,
-                               album_md5);
-  g_free (album_md5);
-  g_free (artist_md5);
-
-  if (g_file_test (file_path, G_FILE_TEST_EXISTS)) {
-    gchar *thumbnail_uri = g_filename_to_uri (file_path, NULL, NULL);
+  if (thumbnail_uri) {
     grl_media_set_thumbnail (rs->media, thumbnail_uri);
     g_free (thumbnail_uri);
-    g_free (file_path);
   }
   rs->callback (rs->source, rs->operation_id, rs->media, rs->user_data, NULL);
 
