@@ -223,20 +223,10 @@ grl_shoutcast_source_finalize (GObject *object)
 {
   GrlShoutcastSource *self = GRL_SHOUTCAST_SOURCE (object);
 
-  if (self->priv->wc && GRL_IS_NET_WC (self->priv->wc))
-    g_object_unref (self->priv->wc);
-
-  if (self->priv->cancellable && G_IS_CANCELLABLE (self->priv->cancellable))
-    g_cancellable_cancel (self->priv->cancellable);
-
-  if (self->priv->cached_page) {
-    g_free (self->priv->cached_page);
-    self->priv->cached_page = NULL;
-  }
-
-  if (self->priv->dev_key) {
-    g_free (self->priv->dev_key);
-  }
+  g_clear_object (&self->priv->wc);
+  g_clear_pointer (&self->priv->cancellable, g_cancellable_cancel);
+  g_clear_pointer (&self->priv->cached_page, g_free);
+  g_clear_pointer (&self->priv->dev_key, g_free);
 
   G_OBJECT_CLASS (grl_shoutcast_source_parent_class)->finalize (object);
 }
@@ -336,9 +326,7 @@ build_media_from_station (OperationData *op_data)
   g_free (station_bitrate);
   g_free (media_id);
   g_free (media_url);
-  if (station_genres) {
-    g_strfreev (station_genres);
-  }
+  g_clear_pointer (&station_genres, g_strfreev);
 
   return media;
 }
@@ -396,6 +384,7 @@ xml_parse_result (const gchar *str, OperationData *op_data)
   xmlNodePtr node;
   xmlXPathContextPtr xpath_ctx;
   xmlXPathObjectPtr xpath_res;
+  guint id;
 
   if (op_data->cancelled) {
     op_data->result_cb (op_data->source,
@@ -462,9 +451,7 @@ xml_parse_result (const gchar *str, OperationData *op_data)
                              _("Cannot find media %s"),
                              grl_media_get_id (op_data->media));
       }
-      if (xpath_res) {
-        xmlXPathFreeObject (xpath_res);
-      }
+      g_clear_pointer (&xpath_res, xmlXPathFreeObject);
       xmlXPathFreeContext (xpath_ctx);
     } else {
       error = g_error_new_literal (GRL_CORE_ERROR,
@@ -503,9 +490,11 @@ xml_parse_result (const gchar *str, OperationData *op_data)
   }
 
   if (stationlist_result) {
-    g_idle_add ((GSourceFunc) send_stationlist_entries, op_data);
+    id = g_idle_add ((GSourceFunc) send_stationlist_entries, op_data);
+    g_source_set_name_by_id (id, "[shoutcast] send_stationlist_entries");
   } else {
-    g_idle_add ((GSourceFunc) send_genrelist_entries, op_data);
+    id = g_idle_add ((GSourceFunc) send_genrelist_entries, op_data);
+    g_source_set_name_by_id (id, "[shoutcast] send_genrelist_entries");
   }
 
   return;
@@ -519,17 +508,10 @@ xml_parse_result (const gchar *str, OperationData *op_data)
                       error);
 
  free_resources:
-  if (op_data->xml_doc) {
-    xmlFreeDoc (op_data->xml_doc);
-  }
+  g_clear_pointer (&op_data->xml_doc, xmlFreeDoc);
+  g_clear_pointer (&op_data->filter_entry, g_free);
+  g_clear_error (&error);
 
-  if (op_data->filter_entry) {
-    g_free (op_data->filter_entry);
-  }
-
-  if (error) {
-    g_error_free (error);
-  }
   g_slice_free (OperationData, op_data);
 }
 
@@ -580,11 +562,13 @@ read_done_cb (GObject *source_object,
   cache = op_data->cache;
   xml_parse_result (content, op_data);
   if (cache && source->priv->cached_page_expired) {
+    guint id;
     GRL_DEBUG ("Caching page");
     g_free (source->priv->cached_page);
     source->priv->cached_page = g_strdup (content);
     source->priv->cached_page_expired = FALSE;
-    g_timeout_add_seconds (EXPIRE_CACHE_TIMEOUT, expire_cache, source);
+    id = g_timeout_add_seconds (EXPIRE_CACHE_TIMEOUT, expire_cache, source);
+    g_source_set_name_by_id (id, "[shoutcast] expire_cache");
   }
 }
 
@@ -602,8 +586,10 @@ read_url_async (GrlShoutcastSource *source,
                 OperationData *op_data)
 {
   if (op_data->cache && !source->priv->cached_page_expired) {
+    guint id;
     GRL_DEBUG ("Using cached page");
-    g_idle_add ((GSourceFunc) read_cached_page, op_data);
+    id = g_idle_add ((GSourceFunc) read_cached_page, op_data);
+    g_source_set_name_by_id (id, "[shoutcast] read_cached_page");
   } else {
     if (!source->priv->wc)
       source->priv->wc = grl_net_wc_new ();
