@@ -198,6 +198,11 @@ grl_tracker_setup_key_mappings (void)
                       "nfo:entryCounter(?urn)",
                       "directory");
 
+  insert_key_mapping (GRL_METADATA_KEY_SIZE,
+                      NULL,
+                      "nfo:fileSize(?urn)",
+                      "file");
+
   insert_key_mapping_with_setter (GRL_METADATA_KEY_MODIFICATION_DATE,
                                   "nfo:fileLastModified",
                                   "nfo:fileLastModified(?urn)",
