@@ -195,10 +195,7 @@ grl_upnp_plugin_deinit (GrlPlugin *plugin)
 {
   GRL_DEBUG ("grl_upnp_plugin_deinit");
 
-  if (context_manager != NULL) {
-    g_object_unref (context_manager);
-    context_manager = NULL;
-  }
+  g_clear_object (&context_manager);
 }
 
 GRL_PLUGIN_REGISTER (grl_upnp_plugin_init,
@@ -237,6 +234,7 @@ grl_upnp_source_new (const gchar *source_id, const gchar *name, const gchar *ico
   source->priv->upnp_name = g_strdup (name);
 
   g_free (source_desc);
+  g_clear_object (&icon);
 
   return source;
 }
@@ -320,16 +318,25 @@ container_changed_cb (GUPnPServiceProxy *proxy,
   tokens = g_strsplit (g_value_get_string (value), ",", -1);
   changed_medias = g_ptr_array_sized_new (g_strv_length (tokens) / 2);
   while (tokens[i]) {
-    container = grl_media_box_new ();
-    grl_media_set_id (container, tokens[i]);
-    g_ptr_array_add (changed_medias, container);
+    gchar *token;
+
+    token = g_strstrip (tokens[i]);
+    if (token && *token != '\0') {
+      container = grl_media_box_new ();
+      grl_media_set_id (container, tokens[i]);
+      g_ptr_array_add (changed_medias, container);
+    }
     i += 2;
+    if (i > g_strv_length (tokens))
+      break;
   }
 
-  grl_source_notify_change_list (source,
-                                 changed_medias,
-                                 GRL_CONTENT_CHANGED,
-                                 FALSE);
+  if (changed_medias->len > 0) {
+    grl_source_notify_change_list (source,
+                                   changed_medias,
+                                   GRL_CONTENT_CHANGED,
+                                   FALSE);
+  }
   g_strfreev (tokens);
 }
 
@@ -894,8 +901,7 @@ get_thumbnail (GList *nodes)
     if (is_http_get (node)) {
       counter++;
       if (is_image (node)) {
-        if (val)
-          g_free (val);
+        g_clear_pointer (&val, g_free);
         val = (gchar *) xmlNodeGetContent (node);
 
         if (has_thumbnail_marker (node))  /* that's definitely it! */
@@ -907,8 +913,7 @@ get_thumbnail (GList *nodes)
   if (val && counter == 1) {
     /* There was only one element with http-get protocol: that's the uri of the
      * media itself, not a thumbnail */
-    g_free (val);
-    val = NULL;
+    g_clear_pointer (&val, g_free);
   }
 
   return val;
@@ -1098,9 +1103,7 @@ gupnp_browse_cb (GUPnPServiceProxy *service,
     GRL_DEBUG ("Got no results");
     os->callback (os->source, os->operation_id,
                   NULL, 0, os->user_data, error? error: NULL);
-    if (error) {
-      g_error_free (error);
-    }
+    g_clear_error (&error);
 
     goto free_resources;
   }
@@ -1168,9 +1171,7 @@ gupnp_resolve_cb (GUPnPServiceProxy *service,
   if (!didl || !returned) {
     GRL_DEBUG ("Got no results for resolve");
     rs->callback (rs->source, rs->operation_id, rs->media, rs->user_data, error? error: NULL);
-    if (error) {
-      g_error_free (error);
-    }
+    g_clear_error (&error);
 
     goto free_resources;
   }
