@@ -162,11 +162,8 @@ grl_vimeo_plugin_init (GrlRegistry *registry,
   init_result = TRUE;
 
  go_out:
-
-  if (vimeo_key != NULL)
-    g_free (vimeo_key);
-  if (vimeo_secret != NULL)
-    g_free (vimeo_secret);
+  g_clear_pointer (&vimeo_key, g_free);
+  g_clear_pointer (&vimeo_secret, g_free);
 
   return init_result;
 }
@@ -182,6 +179,7 @@ grl_vimeo_source_new (void)
 {
   GIcon *icon;
   GFile *file;
+  GrlVimeoSource *source;
 
   GRL_DEBUG ("grl_vimeo_source_new");
 
@@ -189,13 +187,16 @@ grl_vimeo_source_new (void)
   icon = g_file_icon_new (file);
   g_object_unref (file);
 
-  return g_object_new (GRL_VIMEO_SOURCE_TYPE,
-                       "source-id", SOURCE_ID,
-                       "source-name", SOURCE_NAME,
-                       "source-desc", SOURCE_DESC,
-                       "supported-media", GRL_MEDIA_TYPE_VIDEO,
-                       "source-icon", icon,
-                       NULL);
+  source = g_object_new (GRL_VIMEO_SOURCE_TYPE,
+                         "source-id", SOURCE_ID,
+                         "source-name", SOURCE_NAME,
+                         "source-desc", SOURCE_DESC,
+                         "supported-media", GRL_MEDIA_TYPE_VIDEO,
+                         "source-icon", icon,
+                         NULL);
+  g_object_unref (icon);
+
+  return source;
 }
 
 static void
